@@ -10,7 +10,7 @@ import os
 import functools
 import logging
 from pathlib import Path
-import datetime
+
 from casperlabs_client import (
     CasperLabsClient,
     DEFAULT_HOST,
@@ -18,7 +18,7 @@ from casperlabs_client import (
     DEFAULT_INTERNAL_PORT,
     bundled_contract,
 )
-from casperlabs_client.utils import hexify
+from casperlabs_client.utils import hexify, jsonify
 from casperlabs_client.abi import ABI
 from casperlabs_client.crypto import (
     read_pem_key,
@@ -378,12 +378,16 @@ def stream_events_command(casperlabs_client, args):
         account_public_keys=args.account_public_key,
         deploy_hashes=args.deploy_hash,
         min_event_id=args.min_event_id,
+        max_event_id=args.max_event_id,
         **subscribed_events,
     )
     for event in stream:
-        now = datetime.datetime.now()
-        print(f"------------- {now.strftime('%Y-%m-%d %H:%M:%S')} -------------")
-        print(hexify(event))
+        if args.format == "binary":
+            print(base64.b64encode(event.SerializeToString()).decode())
+        elif args.format == "json":
+            print(jsonify(event))
+        else:
+            print(hexify(event))
 
 
 def check_directory(path):
@@ -450,6 +454,12 @@ def deploy_options(private_key_accepted=True):
 # fmt:on
 
 
+def read_version() -> str:
+    version_path = f"{os.path.dirname(os.path.realpath(__file__))}/VERSION"
+    with open(version_path, 'r') as f:
+        return f.read().strip()
+
+
 def cli(*arguments) -> int:
     """
     Parse list of command line arguments and call appropriate command.
@@ -503,6 +513,11 @@ def cli(*arguments) -> int:
                 type=str,
                 help="Certificate file for TLS connection",
             )
+            self.parser.add_argument(
+                "--version",
+                action="version",
+                version=read_version(),
+            )
             self.sp = self.parser.add_subparsers(help="Choose a request")
 
             def no_command(casperlabs_client, args):
@@ -627,7 +642,9 @@ def cli(*arguments) -> int:
         [('--deploy-orphaned',), dict(action='store_true', help='Deploy orphaned')],
         [('-k', '--account-public-key'), dict(action='append', help='Filter by (possibly multiple) account public key(s)')],
         [('-d', '--deploy-hash'), dict(action='append', help='Filter by (possibly multiple) deploy hash(es)')],
+        [('-f', '--format'), dict(required=False, default='text', choices=('json', 'binary', 'text'), help='Choose output format. Defaults to text representation.')],
         [('--min-event-id',), dict(required=False, default=0, type=int, help="Supports replaying events from a given ID. If the value is 0, it it will subscribe to future events; if it's non-zero, it will replay all past events from that ID, without subscribing to new. To catch up with events from the beginning, start from 1.")],
+        [('--max-event-id',), dict(required=False, default=0, type=int, help="Supports replaying events to a given ID.")],
     ])
     # fmt:on
     return parser.run([str(a) for a in arguments])
